==> qmmp-0.5.2.tar.bz2: qmmp-0.5.2/src/plugins/Transports/mms/translations/mms_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>MMSInputFactory</name>
    <message>
        <location filename="../mmsinputfactory.cpp" line="34"/>
        <source>MMS Plugin</source>
        <translation>MMS プラグイン</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="54"/>
        <source>About MMS Transport Plugin</source>
        <translation>MMS 搬送プラグインについて</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="55"/>
        <source>Qmmp MMS Transport Plugin</source>
        <translation>QMMP MMS 搬送プラグイン</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="56"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MMS Plugin Settings</source>
        <translation>MMS プラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>バッファ容量:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>KiB</translation>
    </message>
</context>
</TS>

==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Transports/mms/translations/mms_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>MMSInputFactory</name>
    <message>
        <location filename="../mmsinputfactory.cpp" line="33"/>
        <source>MMS Plugin</source>
        <translation>MMS プラグイン</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="53"/>
        <source>About MMS Transport Plugin</source>
        <translation>MMS 搬送プラグインについて</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="54"/>
        <source>Qmmp MMS Transport Plugin</source>
        <translation>QMMP MMS 搬送プラグイン</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MMS Plugin Settings</source>
        <translation>MMS プラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>バッファー容量:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>KiB</translation>
    </message>
</context>
</TS>
